@@ -37,8 +37,6 @@ import uuid
 import warnings
 import sympy
 
-import six
-
 import optlang
 from optlang.exceptions import IndicatorConstraintsNotSupported
 
@@ -165,10 +163,6 @@ class Variable(symbolics.Symbol):
 
     def __init__(self, name, lb=None, ub=None, type="continuous", problem=None, *args, **kwargs):
 
-        # Ensure that name is str and not unicode - some solvers only support string type in Python 2.
-        if six.PY2:
-            name = str(name)
-
         self.__validate_variable_name(name)
 
         self._name = name
@@ -414,9 +408,6 @@ class OptimizationExpression(object):
         return adjusted_expression
 
     def __init__(self, expression, name=None, problem=None, sloppy=False, *args, **kwargs):
-        # Ensure that name is str and not unicode - some solvers only support string type in Python 2.
-        if six.PY2 and name is not None:
-            name = str(name)
 
         self._validate_optimization_expression_name(name)
 
