@@ -13,8 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import division
-
 import abc
 import copy
 import json
@@ -23,7 +21,6 @@ import pickle
 import unittest
 from functools import partial
 
-import six
 import sympy
 
 import optlang
@@ -36,8 +33,7 @@ TESTMODELPATH = os.path.join(os.path.dirname(__file__), 'data/model.json')
 TESTMILPMODELPATH = os.path.join(os.path.dirname(__file__), 'data/simple_milp.json')
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractVariableTestCase(unittest.TestCase):
+class AbstractVariableTestCase(unittest.TestCase, metaclass=abc.ABCMeta):
     @unittest.skip('Abstract test method not implemented.')
     def test_magic(self):
         pass
@@ -179,8 +175,7 @@ class AbstractVariableTestCase(unittest.TestCase):
         self.assertEqual(self.var.name, 'test')
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractConstraintTestCase(unittest.TestCase):
+class AbstractConstraintTestCase(unittest.TestCase, metaclass=abc.ABCMeta):
 
     def setUp(self):
         with open(TESTMODELPATH) as infile:
@@ -365,8 +360,7 @@ class AbstractConstraintTestCase(unittest.TestCase):
         self.assertTrue(const.get_linear_coefficients([x, y, z, w]) == {x: 1, y: 1, z: 1, w: 0})
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractObjectiveTestCase(unittest.TestCase):
+class AbstractObjectiveTestCase(unittest.TestCase, metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def setUp(self):
         pass
@@ -416,8 +410,7 @@ class AbstractObjectiveTestCase(unittest.TestCase):
         self.assertTrue(obj.get_linear_coefficients([x, y, z, w]) == {x: 1, y: 1, z: 1, w: 0})
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractModelTestCase(unittest.TestCase):
+class AbstractModelTestCase(unittest.TestCase, metaclass=abc.ABCMeta):
 
     def setUp(self):
         with open(TESTMODELPATH) as infile:
@@ -976,8 +969,7 @@ class AbstractModelTestCase(unittest.TestCase):
         self.assertEqual(const.name, old_name)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractConfigurationTestCase(unittest.TestCase):
+class AbstractConfigurationTestCase(unittest.TestCase, metaclass=abc.ABCMeta):
 
     def setUp(self):
         pass
@@ -994,8 +986,7 @@ class AbstractConfigurationTestCase(unittest.TestCase):
             )
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractQuadraticProgrammingTestCase(unittest.TestCase):
+class AbstractQuadraticProgrammingTestCase(unittest.TestCase, metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def setUp(self):
         pass
