@@ -22,7 +22,6 @@ else:
     import json
 
     import numpy as np
-    import six
     from numpy.testing import assert_allclose
 
     from optlang import interface, hybrid_interface
@@ -432,6 +431,13 @@ else:
             self.assertEqual(self.model.problem.obj_linear_coefs,
                 {self.model.variables[2].name: 1.0})
 
+        def test_check_for_valid_solution(self):
+            self.model.optimize()
+            form = self.model.problem.build(True)
+            self.assertTrue(self.model.problem.still_valid(form))
+            form = self.model.problem.build(False)
+            self.assertTrue(self.model.problem.still_valid(form))
+
 
     class ConfigurationTestCase(abstract_test_cases.AbstractConfigurationTestCase):
 
@@ -515,7 +521,7 @@ else:
             assert_allclose(self.x1.primal, 0.0, TOL, TOL)
 
         def test_qp_convex(self):
-            for qp, info in six.iteritems(LARGE_QPS):
+            for qp, info in LARGE_QPS.items():
                 nv, nc, ref_sol = info
                 prob = json.load(open(qp))
                 model = Model.from_json(prob)
